==> DI-engine-0.4.4.tar.gz: DI-engine-0.4.4/ding/rl_utils/__init__.py <==
from .exploration import get_epsilon_greedy_fn, create_noise_generator
from .ppo import ppo_data, ppo_loss, ppo_info, ppo_policy_data, ppo_policy_error, ppo_value_data, ppo_value_error,\
    ppo_error, ppo_error_continuous, ppo_policy_error_continuous
from .ppg import ppg_data, ppg_joint_loss, ppg_joint_error
from .gae import gae_data, gae
from .a2c import a2c_data, a2c_error
from .coma import coma_data, coma_error
from .td import q_nstep_td_data, q_nstep_td_error, q_1step_td_data, q_1step_td_error, td_lambda_data, td_lambda_error,\
    q_nstep_td_error_with_rescale, v_1step_td_data, v_1step_td_error, v_nstep_td_data, v_nstep_td_error, \
    generalized_lambda_returns, dist_1step_td_data, dist_1step_td_error, dist_nstep_td_error, dist_nstep_td_data, \
    nstep_return_data, nstep_return, iqn_nstep_td_data, iqn_nstep_td_error, qrdqn_nstep_td_data, qrdqn_nstep_td_error,\
    fqf_nstep_td_data, fqf_nstep_td_error, fqf_calculate_fraction_loss, evaluate_quantile_at_action, \
    q_nstep_sql_td_error, dqfd_nstep_td_error, dqfd_nstep_td_data, q_v_1step_td_error, q_v_1step_td_data,\
    dqfd_nstep_td_error_with_rescale, discount_cumsum
from .vtrace import vtrace_loss, compute_importance_weights
from .upgo import upgo_loss
from .adder import get_gae, get_gae_with_default_last_value, get_nstep_return_data, get_train_sample
from .value_rescale import value_transform, value_inv_transform
from .vtrace import vtrace_data, vtrace_error
from .beta_function import beta_function_map
from .retrace import compute_q_retraces
from .acer import acer_policy_error, acer_value_error, acer_trust_region_update

==> DI-engine-0.4.6.tar.gz: DI-engine-0.4.6/ding/rl_utils/__init__.py <==
from .exploration import get_epsilon_greedy_fn, create_noise_generator
from .ppo import ppo_data, ppo_loss, ppo_info, ppo_policy_data, ppo_policy_error, ppo_value_data, ppo_value_error,\
    ppo_error, ppo_error_continuous, ppo_policy_error_continuous
from .ppg import ppg_data, ppg_joint_loss, ppg_joint_error
from .gae import gae_data, gae
from .a2c import a2c_data, a2c_error
from .coma import coma_data, coma_error
from .td import q_nstep_td_data, q_nstep_td_error, q_1step_td_data, q_1step_td_error, td_lambda_data, td_lambda_error,\
    q_nstep_td_error_with_rescale, v_1step_td_data, v_1step_td_error, v_nstep_td_data, v_nstep_td_error, \
    generalized_lambda_returns, dist_1step_td_data, dist_1step_td_error, dist_nstep_td_error, dist_nstep_td_data, \
    nstep_return_data, nstep_return, iqn_nstep_td_data, iqn_nstep_td_error, qrdqn_nstep_td_data, qrdqn_nstep_td_error,\
    fqf_nstep_td_data, fqf_nstep_td_error, fqf_calculate_fraction_loss, evaluate_quantile_at_action, \
    q_nstep_sql_td_error, dqfd_nstep_td_error, dqfd_nstep_td_data, q_v_1step_td_error, q_v_1step_td_data,\
    dqfd_nstep_td_error_with_rescale, discount_cumsum, bdq_nstep_td_error
from .vtrace import vtrace_loss, compute_importance_weights
from .upgo import upgo_loss
from .adder import get_gae, get_gae_with_default_last_value, get_nstep_return_data, get_train_sample
from .value_rescale import value_transform, value_inv_transform
from .vtrace import vtrace_data, vtrace_error_discrete_action, vtrace_error_continuous_action
from .beta_function import beta_function_map
from .retrace import compute_q_retraces
from .acer import acer_policy_error, acer_value_error, acer_trust_region_update
from .sampler import ArgmaxSampler, MultinomialSampler, MuSampler, ReparameterizationSampler, HybridStochasticSampler, \
    HybridDeterminsticSampler
